@@ -13,12 +13,11 @@ curfnfinder <- function(skipframes=0,
   prefix <- gsub("function \\(.*", "do.call", prefix);
   if(length(prefix)==0) {
     return(retIfNone);
-  }
-  else if(retStack) {
+  } else if(retStack) {
     return(paste(rev(prefix), collapse = "|"));
-  }
-  else {
+  } else {
     res <- as.character(unlist(prefix[1]));
+    res <- unlist(lapply(res, gsub, pattern=".*::", replacement=""));
     if (length(prefix) > 1) {
       res <- paste(paste(rep(extraPrefPerLevel, length(prefix) - 1), collapse=""), res, sep="");
     }
